/*-----------------------------------------------------------------------
esurban_table5.do

Stata do file to replicate table 5 of the article
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies
-----------------------------------------------------------------------*/

* Initialise
clear all
set more off
set matsize 2000
quietly capture log close
log using ../../output/esurban_table5, text replace

* Read panel
use ../../output/mcvl_panel, clear

* Produce LaTeX table
gen row = 7
replace row = 1 if ua_1_2 == 1
replace row = 4 if ua_3_5 == 1
table row, c(mean skill_1 mean skill_2 mean skill_3 mean skill_4 mean skill_5) replace format(%9.0g)
forvalues sl = 1(1)5 {
  gen skill_`sl' = string(100 * table`sl', "%8.1f") + "\%"
}
local newobs = _N + 5
set obs `newobs'
sort row
replace row = _n if missing(row)
replace row = 2 if row == 4 & missing(table1)
replace row = 3 if row == 7 & missing(table1)
sort row
gen size_description = ""
replace size_description = "1$^\text{st}$-2$^\text{nd}$ biggest cities" if row == 1
replace size_description = "3$^\text{rd}$-5$^\text{th}$ biggest cities" if row == 4
replace size_description = "Other cities" if row == 7
replace size_description = "\midrule" if row == 3 | row == 6
gen str1 ampersand = "&"
replace ampersand = "" if row == 3 | row == 6
gen str4 slash = "\\"
replace slash = "" if row == 3 | row == 6
outsheet size_description ampersand skill_1 ampersand skill_2 ampersand skill_3 ampersand skill_4 ampersand skill_5 slash using ../../output/esurban_table5.tex, nonames noquote replace

log close
