/*-----------------------------------------------------------------------
mcvl_reading_2004.do

Stata do file used to recreate the panel for
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies

Reads MCVL CDF 2004 source data sets
-----------------------------------------------------------------------*/

** MCVL 2004 uses space delimiter
forval n = 1/3 {
  shell sed 's/ /;/g' "../../mcvl/mcvl_cdf_2004/AFILANON`n'.txt" > "../../tmp/mcvl_cdf_2004/AFILANON`n'_.txt"
  shell sed 's/;;;/  ;/g' "../../tmp/mcvl_cdf_2004/AFILANON`n'_.txt" > "../../tmp/mcvl_cdf_2004/AFILANON`n'__.txt"
  shell sed 's/;;/ ;/g' "../../tmp/mcvl_cdf_2004/AFILANON`n'__.txt" > "../../tmp/mcvl_cdf_2004/AFILANON`n'.txt"
  erase "../../tmp/mcvl_cdf_2004/AFILANON`n'_.txt"
  erase "../../tmp/mcvl_cdf_2004/AFILANON`n'__.txt"
}
forval n = 1/13 {
  shell sed 's/ /;/g' "../../mcvl/mcvl_cdf_2004/COTIANON`n'.txt" > "../../tmp/mcvl_cdf_2004/COTIANON`n'.txt"
}
shell sed 's/ /;/g' "../../mcvl/mcvl_cdf_2004/PERSANON.txt" > "../../tmp/mcvl_cdf_2004/PERSANON_.txt"
shell sed 's/;;;;/;  ;/g' "../../tmp/mcvl_cdf_2004/PERSANON_.txt" > "../../tmp/mcvl_cdf_2004/PERSANON.txt"
erase "../../tmp/mcvl_cdf_2004/PERSANON_.txt"

** Individuals
insheet using "../../tmp/mcvl_cdf_2004/PERSANON.txt", clear delimiter(";")
rename v1 person_id
rename v2 birth_date
rename v3 sex
rename v4 nationality
rename v5 birth_prov
rename v6 ss_reg_prov
rename v7 person_muni_latest
rename v8 death_year_month
gen birth_country = .
gen edu_code = .
label var person_id "Individual identifier"
label var birth_date "Birth date"
label var sex "Sex: Male=1 Female=2"
label var birth_date "Birth year-month"
label var death_year_month "Month deceased"
label var birth_prov "Birth province"
label var birth_country "Birth country"
label var nationality "Nationality"
label var person_muni_latest "Municipality of residence from municipal registry"
label var ss_reg_prov "Province of social security registration"
label var edu_code "Education from municipal registry"
* Drop individuals with missing sex information
drop if sex == 0 | sex == 9
* Check for duplicate person_id
* Drop under-aged
egen count = seq(), by (person_id)
egen maxcount = max(count), by (person_id)
destring birth_date, replace
drop if maxcount > 1 & birth_date >= 198700
* Some individuals appear twice, varying only in ss_reg_prov (typically 0 in one), keep once
drop count maxcount
egen count = seq(), by (person_id)
egen maxcount = max(count), by (person_id)
gsort person_id -ss_reg_prov
drop if (maxcount > 1) & (person_id[_n] == person_id[_n-1]) & (birth_date[_n] == birth_date[_n-1]) & (sex[_n] == sex[_n-1])
* Final few repeats are rare individuals given ID number still in use prior to computerisation of ID records
drop count maxcount
egen count = seq(), by (person_id)
egen maxcount = max(count), by (person_id)
drop if maxcount > 1
drop count maxcount
save "../../tmp/mcvl_cdf_2004/individuals", replace

** Affiliates
foreach num of numlist 1/3 {
  insheet using "../../tmp/mcvl_cdf_2004/AFILANON`num'.txt", clear delimiter(";")
  rename v1 person_id        
  rename v2 regime
  rename v3 occupation                  
  rename v4 contract_type
  rename v5 ptcoef
  rename v6 entry_date
  rename v7 exit_date
  rename v8 reason_dismissal
  rename v9 disability
  rename v10 firm_id_sec
  rename v11 firm_muni
  rename v12 sector_cnae93
  rename v13 firm_workers
  rename v14 firm_age
  rename v15 job_relationship
  rename v16 firm_ett
  rename v17 firm_jur_type
  rename v18 firm_jur_status
  rename v19 firm_id_main
  rename v20 firm_main_prov
  recode job_relationship 999 = 0
  label var person_id "Individual identifier"
  label var regime "Social security regime"
  label var occupation "Occupational code"
  label var contract_type "Type of job contract"
  label var ptcoef "Part time coefficient in 1/1000 of full-time equivalent, 0 if full-time"
  label var entry_date "Date of entry in this affiliation"
  label var exit_date "Date of exit in this affiliation"
  label var reason_dismissal "Reason for dismissal in this affiliation"
  label var disability "Type of disability according to entry in affiliation"
  label var firm_id_sec "Firm establishment identifier"
  label var firm_muni "Firm establishment municipality if population above 40000"
  label var sector_cnae93 "3-digit sector code"
  label var firm_workers "Number of workers in firm establsihment"
  label var firm_age "Date firm establishment registered its first worker"
  label var job_relationship "Type of job relationship"
  label var firm_ett "Firm establishment is a temporary recruitment agency (ETT)"
  label var firm_jur_type "Firm establishment juridical classification (natural vs. legal entities)"
  label var firm_jur_status "Firm establishment juridical status (NIF for legal entities)"
  label var firm_id_main "Common firm identifier for multi-establishment firm"
  label var firm_main_prov "Province associated with common firm identifier"
  sort person_id entry_date exit_date firm_id_sec
  save "../../tmp/mcvl_cdf_2004/affiliates_`num'", replace
}

** Contributions

* Contributions 1-12
foreach num of numlist 1/12 {
  insheet using "../../tmp/mcvl_cdf_2004/COTIANON`num'.txt", clear delimiter(";")
  rename v1 person_id        
  rename v2 firm_id_sec                  
  rename v3 entry_date                 
  rename v5 exit_date               
  rename v7 occupation                  
  rename v8 year
  rename v9 earnings_jan
  rename v11 earnings_feb
  rename v13 earnings_mar
  rename v15 earnings_apr
  rename v17 earnings_may
  rename v19 earnings_jun
  rename v21 earnings_jul
  rename v23 earnings_aug
  rename v25 earnings_sep
  rename v27 earnings_oct
  rename v29 earnings_nov
  rename v31 earnings_dec
  rename v35 contract_type
  drop v4 v6 v10 v12 v14 v16 v18 v20 v22 v24 v26 v28 v30 v32-v34 
  label var person_id "Individual identifier"
  label var firm_id_sec "Firm identifier for secondary establishment"
  label var entry_date "Date of entry in this affiliation"
  label var exit_date "Date of exit in this affiliation"
  label var occupation "Occupational code in pension contribution file"
  label var year "Year"
  label var earnings_jan "Pension contribution-January (nominal euros in cents)"
  label var earnings_feb "Pension contribution-February (nominal euros in cents)"
  label var earnings_mar "Pension contribution-March (nominal euros in cents)"
  label var earnings_apr "Pension contribution-April (nominal euros in cents)"
  label var earnings_may "Pension contribution-May (nominal euros in cents)"
  label var earnings_jun "Pension contribution-June (nominal euros in cents)"
  label var earnings_jul "Pension contribution-July (nominal euros in cents)"
  label var earnings_aug "Pension contribution-August (nominal euros in cents)"
  label var earnings_sep "Pension contribution-September (nominal euros in cents)"
  label var earnings_oct "Pension contribution-October (nominal euros in cents)"
  label var earnings_nov "Pension contribution-November (nominal euros in cents)"
  label var earnings_dec "Pension contribution-December (nominal euros in cents)"
  label var contract_type "Type of job contract in pension contribution file"
  sort person_id entry_date exit_date firm_id_sec
  save "../../tmp/mcvl_cdf_2004/contribution_`num'", replace
}
      
* Contribution 13
insheet using "../../tmp/mcvl_cdf_2004/COTIANON13.txt", clear delimiter(";")
rename v1 person_id        
rename v2 firm_id_sec                  
rename v3 entry_date                 
rename v5 exit_date               
rename v7 year
rename v8 earnings_jan
rename v9 earnings_feb
rename v10 earnings_mar
rename v11 earnings_apr
rename v12 earnings_may
rename v13 earnings_jun
rename v14 earnings_jul
rename v15 earnings_aug
rename v16 earnings_sep
rename v17 earnings_oct
rename v18 earnings_nov
rename v19 earnings_dec
drop v4 v6
label var person_id "Individual identifier"
label var firm_id_sec "Firm identifier for secondary establishment"
label var entry_date "Date of entry in this affiliation"
label var exit_date "Date of exit in this affiliation"
label var year "Year"
label var earnings_jan "Pension contribution-January (nominal euros in cents)"
label var earnings_feb "Pension contribution-February (nominal euros in cents)"
label var earnings_mar "Pension contribution-March (nominal euros in cents)"
label var earnings_apr "Pension contribution-April (nominal euros in cents)"
label var earnings_may "Pension contribution-May (nominal euros in cents)"
label var earnings_jun "Pension contribution-June (nominal euros in cents)"
label var earnings_jul "Pension contribution-July (nominal euros in cents)"
label var earnings_aug "Pension contribution-August (nominal euros in cents)"
label var earnings_sep "Pension contribution-September (nominal euros in cents)"
label var earnings_oct "Pension contribution-October (nominal euros in cents)"
label var earnings_nov "Pension contribution-November (nominal euros in cents)"
label var earnings_dec "Pension contribution-December (nominal euros in cents)"
sort person_id entry_date exit_date firm_id_sec
save "../../tmp/mcvl_cdf_2004/contribution_13", replace

** Erase temporary data sets

forval n = 1/3 {
  erase "../../tmp/mcvl_cdf_2004/AFILANON`n'.txt"
}
forval n = 1/13 {
  erase "../../tmp/mcvl_cdf_2004/COTIANON`n'.txt"
}
erase "../../tmp/mcvl_cdf_2004/PERSANON.txt"
