/*-----------------------------------------------------------------------
mcvl_reading_tax_data.do

Stata do file used to recreate the panel for
'Learning by working in big cities',
by Jorge De la Roca and Diego Puga,
Review of Economic Studies

Reads MCVL CDF 2004-2013 tax earnings data sets
-----------------------------------------------------------------------*/

** Tax data 2004
clear
infix v1 1-15 v2 16-30 v3 31-32 str v4 33 v5 34-35 double v6 36-47 double v7 48-59 double v8 60-71 using "../../mcvl/mcvl_cdf_2004/BLOQUE5.txt", clear
rename v1 person_id
rename v2 firm_id_tax
rename v3 person_province
rename v4 payment_type
rename v5 payment_subtype
rename v6 payment_amount
rename v7 payment_retention
rename v8 payment_inkind
label var person_id "Individual identifier"
label var firm_id_tax "Firm identifier for matching with tax data"
label var person_province "Province of individual residence in tax data"
label var payment_type "Type of payment (salary, pension, unemployment benefit,prizes, etc.)"
label var payment_subtype "Subtype of payment classification (when applicable)"
label var payment_amount "Payment amount (nominal euros in cents)"
label var payment_retention "Payment retentions for taxes (nominal euros in cents)"
label var payment_inkind "Payment in-kind (nominal euros in cents)"
sort person_id
save "../../tmp/mcvl_cdf_2004/tax", replace

** Tax data 2005
clear
insheet using "../../mcvl/mcvl_cdf_2005/BLOQUE5.trs", clear delimiter(";")
rename v1 person_id
rename v2 firm_jur_status
rename v3 firm_id_tax
rename v4 person_province
rename v5 payment_type
rename v6 payment_subtype
rename v7 payment_amount
rename v8 payment_retention
rename v9 payment_inkind
rename v13 birth_year
rename v14 marital_status
rename v15 disability
rename v16 contract_type
drop v10 - v12 v17 - v44 
label var person_id "Individual identifier"
label var firm_jur_status "Firm juridical status (NIF for legal entities)"
label var firm_id_tax "Firm identifier for matching with tax data"
label var person_province "Province of individual residence in tax data"
label var payment_type "Type of payment (salary, pension, unemployment benefit,prizes, etc.)"
label var payment_subtype "Subtype of payment classification (when applicable)"
label var payment_amount "Payment amount (nominal euros in cents)"
label var payment_retention "Payment retentions for taxes (nominal euros in cents)"
label var payment_inkind "Payment in-kind (nominal euros in cents)"
label var birth_year "Birth year in tax data"
label var marital_status "Marital status in tax data (non-compulsory)"
label var disability "Degree of disability in tax data"
label var contract_type "Type of job contract in tax data"
sort person_id
save "../../tmp/mcvl_cdf_2005/tax", replace

** Tax data 2006-2008
foreach num of numlist 2006/2008 {
  clear
  insheet using "../../mcvl/mcvl_cdf_`num'/DATOS_FISCALES.trs", clear delimiter(";")
  rename v1 person_id
  rename v2 firm_jur_status
  rename v3 firm_id_tax
  rename v4 person_province
  rename v5 payment_type
  rename v6 payment_subtype
  rename v7 payment_amount
  rename v8 payment_retention
  rename v9 payment_inkind
  rename v13 birth_year
  rename v14 marital_status
  rename v15 disability
  rename v16 contract_type
  drop v10 - v12 v17 - v44 
  label var person_id "Individual identifier"
  label var firm_jur_status "Firm juridical status (NIF for legal entities)"
  label var firm_id_tax "Firm identifier for matching with tax data"
  label var person_province "Province of individual residence in tax data"
  label var payment_type "Type of payment (salary, pension, unemployment benefit,prizes, etc.)"
  label var payment_subtype "Subtype of payment classification (when applicable)"
  label var payment_amount "Payment amount (nominal euros in cents)"
  label var payment_retention "Payment retentions for taxes (nominal euros in cents)"
  label var payment_inkind "Payment in-kind (nominal euros in cents)"
  label var birth_year "Birth year in tax data"
  label var marital_status "Marital status in tax data (non-compulsory)"
  label var disability "Degree of disability in tax data"
  label var contract_type "Type of job contract in tax data"
  sort person_id
  save "../../tmp/mcvl_cdf_`num'/tax", replace
}

** Tax data 2009-2012
foreach num of numlist 2009/2012 {
  clear
  insheet using "../../mcvl/mcvl_cdf_`num'/MCVL`num'FISCAL_CDF.TXT", clear delimiter(";")
  rename v1 person_id
  rename v2 firm_jur_status
  rename v3 firm_id_tax
  rename v4 person_province
  rename v5 payment_type
  rename v6 payment_subtype
  rename v7 payment_amount
  rename v8 payment_retention
  rename v9 payment_inkind
  rename v13 birth_year
  rename v14 marital_status
  rename v15 disability
  rename v16 contract_type
  drop v10 - v12 v17 - v44 
  label var person_id "Individual identifier"
  label var firm_jur_status "Firm juridical status (NIF for legal entities)"
  label var firm_id_tax "Firm identifier for matching with tax data"
  label var person_province "Province of individual residence in tax data"
  label var payment_type "Type of payment (salary, pension, unemployment benefit,prizes, etc.)"
  label var payment_subtype "Subtype of payment classification (when applicable)"
  label var payment_amount "Payment amount (nominal euros in cents)"
  label var payment_retention "Payment retentions for taxes (nominal euros in cents)"
  label var payment_inkind "Payment in-kind (nominal euros in cents)"
  label var birth_year "Birth year in tax data"
  label var marital_status "Marital status in tax data (non-compulsory)"
  label var disability "Degree of disability in tax data"
  label var contract_type "Type of job contract in tax data"
  sort person_id
  save "../../tmp/mcvl_cdf_`num'/tax", replace
}

** Tax data 2013
clear
insheet using "../../mcvl/mcvl_cdf_2013/MCVL2012FISCAL_CDF.TXT", clear delimiter(";")
rename v1 person_id
rename v2 firm_jur_status
rename v3 firm_id_tax
rename v4 person_province
rename v5 payment_type
rename v6 payment_subtype
rename v7 payment_amount
rename v8 payment_retention
rename v9 payment_inkind
rename v13 birth_year
rename v14 marital_status
rename v15 disability
rename v16 contract_type
drop v10 - v12 v17 - v44 
label var person_id "Individual identifier"
label var firm_jur_status "Firm juridical status (NIF for legal entities)"
label var firm_id_tax "Firm identifier for matching with tax data"
label var person_province "Province of individual residence in tax data"
label var payment_type "Type of payment (salary, pension, unemployment benefit,prizes, etc.)"
label var payment_subtype "Subtype of payment classification (when applicable)"
label var payment_amount "Payment amount (nominal euros in cents)"
label var payment_retention "Payment retentions for taxes (nominal euros in cents)"
label var payment_inkind "Payment in-kind (nominal euros in cents)"
label var birth_year "Birth year in tax data"
label var marital_status "Marital status in tax data (non-compulsory)"
label var disability "Degree of disability in tax data"
label var contract_type "Type of job contract in tax data"
sort person_id
save "../../tmp/mcvl_cdf_2013/tax", replace
